/* $Workfile: Dsp54Ioctl.h $   $Revision: 5 $    $Modtime: 3/20/03 1:44p $  */
#ifndef DSP54_IOCTL_H
#define DSP54_IOCTL_H
/*------------------------------------------------------- File Description -*\

  @doc PublicDspSdkApi Dsp54Ioctl

  Odin TeleSystems Inc.

  SAA-1007-1 OTX DSP C54x Software Development Kit (SDK)

  @module

    Dsp54Ioctl.h | Macros and structs for sharing data between a C54x DSP and the host.

  @index enum struct type | Dsp54Ioctl

  @contents2
  Dsp54Ioctl.h |

\*--------------------------------------------------------------------------*/

#ifdef HDR_DBG // Define to trace include order of headers
#pragma message("\n" __FILE__ "(1): Including\n")
#endif


#include "DspIoctl.h"
 
#if defined(__linux__) 
#pragma pack(2)
#elif defined(_TMS320C5XX)
// No pack pragma needed for the DSP compiler
#else
#pragma pack(push,2)
#endif



#if 1 // Default HPI buffer configuration
// Asynchronous Notification Events from Dsp To Host 
// @devnote The first two addresses of the HPI (0x1000 and 0x1001) are reserved for the OTX DSP Kernel communication
// @type OTXDSP_SDK_EVENT_BUF_PROCESSING_ADDR | The host writes the current processing address to this location
#define OTXDSP_SDK_EVENT_BUF_PROCESSING_ADDR 0x1002   

// @type OTXDSP_SDK_EVENT_BUF_ADDR | Start address for Circular buffer of event from the DSP to the host
#define OTXDSP_SDK_EVENT_BUF_ADDR            0x1003   

// @type OTXDSP_SDK_EVENT_BUF_LEN | Length of the Circular buffer (in words)
#if defined(_TURNSTONE_) && defined(_MOD_HPI_)

#define OTXDSP_SDK_EVENT_BUF_LEN             0x0320   

#else ////defined(_TURNSTONE_) && defined(_MOD_HPI_)

#define OTXDSP_SDK_EVENT_BUF_LEN             0x05F0   

#endif ////defined(_TURNSTONE_) && defined(_MOD_HPI_)

#define OTXDSP_SDK_EVENT_BUF_INCLUDE_HANDLE 1
#define OTXDSP_SDK_EVENT_BUF_INCLUDE_TASKREF 1
//#define OTXDSP_SDK_EVENT_BUF_INCLUDE_TIMESTAMP 1

// IO CONTROL from Host to Dsp
// @type OTXDSP_SDK_IOCTL_CODE_ADDR |

#if defined(_TURNSTONE_) && defined(_MOD_HPI_)

#define OTXDSP_SDK_IOCTL_CODE_ADDR         0x1330   // Start of the DSP IO Control packet. The host will always wait for the DSP to acknowledge the command (by writing <t OTXDSP_SDK_IO_NO_COMMAND> to this address).

#else //defined(_TURNSTONE_) && defined(_MOD_HPI_)

#define OTXDSP_SDK_IOCTL_CODE_ADDR         0x15F8   // Start of the DSP IO Control packet. The host will always wait for the DSP to acknowledge the command (by writing <t OTXDSP_SDK_IO_NO_COMMAND> to this address).

#endif ////defined(_TURNSTONE_) && defined(_MOD_HPI_)

// @type OTXDSP_SDK_IOCTL_HANDLE_ADDR | Handle of the Logical device (nEventSourceId parameter of <f OtxDrvCreateLogicalDevice>)
#define OTXDSP_SDK_IOCTL_HANDLE_ADDR       (OTXDSP_SDK_IOCTL_CODE_ADDR + 1)   
// @type OTXDSP_SDK_IOCTL_TASKREF_ADDR | Task Reference
#define OTXDSP_SDK_IOCTL_TASKREF_ADDR      (OTXDSP_SDK_IOCTL_HANDLE_ADDR + 1)  
// @type OTXDSP_SDK_IOCTL_DATA_LEN_ADDR | Data length for the command issued by the host
#define OTXDSP_SDK_IOCTL_DATA_LEN_ADDR     (OTXDSP_SDK_IOCTL_TASKREF_ADDR + 1) 
// @type OTXDSP_SDK_IOCTL_DATA_ADDR | Start of data
#define OTXDSP_SDK_IOCTL_DATA_ADDR         (OTXDSP_SDK_IOCTL_DATA_LEN_ADDR + 1)  

// @type OTXDSP_SDK_IOCTL_DATA_MAX_SIZE | Maximum size of Ioctl data
#if defined(_TURNSTONE_) && defined(_MOD_HPI_)

#define OTXDSP_HPI_FREE_ADDR_START      0x1500   
#define OTXDSP_DS0_AUDIO_BUFLEN	   		0x2C0
#define OTXDSP_DS0_AUDIO_BUF_ADDR       (OTXDSP_HPI_FREE_ADDR_START) 

#define OTXDSP_DS0_VISUAL_BUFLEN		0x30
#define OTXDSP_DS0_VISUAL_BUF_ADDR      (OTXDSP_HPI_FREE_ADDR_START + OTXDSP_DS0_AUDIO_BUFLEN + 1)
 
#define OTXDSP_SDK_IOCTL_DATA_MAX_SIZE  (0x1499 - OTXDSP_SDK_IOCTL_DATA_ADDR - 1) // Max Data Length (in words)


#if defined(_DS0_AUDIO_INPUT_)  && defined(_WAVE_INPUT_)
#define OTX_DSP_DS0_AUDIO_INPUTBUF_ADDR  0x1800
#define OTX_DSP_DS0_AUDIO_INPUTBUF_LEN   0xC8
#endif //_DS0_AUDIO_INPUT_ && _WAVE_INPUT_


#else //defined(_TURNSTONE_) && defined(_MOD_HPI_)

#define OTXDSP_SDK_IOCTL_DATA_MAX_SIZE  (0x1800 - OTXDSP_SDK_IOCTL_DATA_ADDR - 1) // Max Data Length (in words)

#endif ////defined(_TURNSTONE_) && defined(_MOD_HPI_)


#else // Overridden HPI buffer configuration (see the attributes of the DSP and the DspDemo1.c demo program)

#define OTXDSP_SDK_EVENT_BUF_PROCESSING_ADDR 0x100F   
#define OTXDSP_SDK_EVENT_BUF_ADDR            0x1010   
#define OTXDSP_SDK_EVENT_BUF_LEN             0x0200   

//#define OTXDSP_SDK_EVENT_BUF_INCLUDE_HANDLE 1
//#define OTXDSP_SDK_EVENT_BUF_INCLUDE_TASKREF 1
//#define OTXDSP_SDK_EVENT_BUF_INCLUDE_TIMESTAMP 1

#define OTXDSP_SDK_IOCTL_CODE_ADDR         0x1300  
#define OTXDSP_SDK_IOCTL_HANDLE_ADDR       (OTXDSP_SDK_IOCTL_CODE_ADDR + 1)    
#define OTXDSP_SDK_IOCTL_TASKREF_ADDR      (OTXDSP_SDK_IOCTL_HANDLE_ADDR + 1)  
#define OTXDSP_SDK_IOCTL_DATA_LEN_ADDR     (OTXDSP_SDK_IOCTL_TASKREF_ADDR + 1) 
#define OTXDSP_SDK_IOCTL_DATA_ADDR         (OTXDSP_SDK_IOCTL_DATA_LEN_ADDR + 1) 
#define OTXDSP_SDK_IOCTL_DATA_MAX_SIZE     0x200 

#endif // HPI Buffer configuration



#if defined(__linux__) 
#pragma pack(2)
#elif defined(_TMS320C5XX)
// No pack pragma needed for the DSP compiler
#else
#pragma pack(pop)
#endif

/******************************************************************************

  Copyright (C) Odin TeleSystems Inc., 1999-2003


  All rights reserved. No part of this computer program may be reproduced,
  stored in any retrieval system, or transmitted, in any form or by any
  means, electronic, mechanical, photocopying, recording, or otherwise,
  without the prior written permission of Odin TeleSystems Inc., or without
  a permission stipulated in the agreement/contract under which this computer
  program was supplied.

******************************************************************************/
#endif /* DSP54_IOCTL_H */
